# -*- coding: utf-8 -*-
"""Zeigen -- find protonated waters in structures.

\b
For complete help visit https://github.com/hydrationdynamics/zeigen
\b
License: BSD-3-Clause
Copyright © 2021, GenerisBio LLC.
All rights reserved.
"""  # noqa: D301
