"""List of RCSB attributes as of 2022-01-26."""
rcsb_attr_list = [
    "pdbx_struct_special_symmetry.PDB_model_num",
    "pdbx_struct_special_symmetry.auth_seq_id",
    "pdbx_struct_special_symmetry.id",
    "pdbx_struct_special_symmetry.label_asym_id",
    "pdbx_struct_special_symmetry.label_comp_id",
    "rcsb_branched_entity_instance_container_identifiers.asym_id",
    "rcsb_branched_entity_instance_container_identifiers.auth_asym_id",
    "rcsb_branched_entity_instance_container_identifiers.entity_id",
    "rcsb_branched_entity_instance_container_identifiers.entry_id",
    "rcsb_branched_entity_instance_container_identifiers.rcsb_id",
    "rcsb_branched_instance_annotation.annotation_id",
    "rcsb_branched_instance_annotation.assignment_version",
    "rcsb_branched_instance_annotation.comp_id",
    "rcsb_branched_instance_annotation.description",
    "rcsb_branched_instance_annotation.name",
    "rcsb_branched_instance_annotation.ordinal",
    "rcsb_branched_instance_annotation.provenance_source",
    "rcsb_branched_instance_annotation.type",
    "rcsb_branched_instance_annotation.annotation_lineage.depth",
    "rcsb_branched_instance_annotation.annotation_lineage.id",
    "rcsb_branched_instance_annotation.annotation_lineage.name",
    "rcsb_branched_instance_feature.assignment_version",
    "rcsb_branched_instance_feature.description",
    "rcsb_branched_instance_feature.feature_id",
    "rcsb_branched_instance_feature.name",
    "rcsb_branched_instance_feature.ordinal",
    "rcsb_branched_instance_feature.provenance_source",
    "rcsb_branched_instance_feature.reference_scheme",
    "rcsb_branched_instance_feature.type",
    "rcsb_branched_instance_feature.feature_positions.beg_comp_id",
    "rcsb_branched_instance_feature.feature_positions.beg_seq_id",
    "rcsb_branched_instance_feature.feature_positions.end_seq_id",
    "rcsb_branched_instance_feature.feature_positions.value",
    "rcsb_branched_instance_feature.feature_value.comp_id",
    "rcsb_branched_instance_feature.feature_value.details",
    "rcsb_branched_instance_feature.feature_value.reference",
    "rcsb_branched_instance_feature.feature_value.reported",
    "rcsb_branched_instance_feature.feature_value.uncertainty_estimate",
    "rcsb_branched_instance_feature.feature_value.uncertainty_estimate_type",
    "rcsb_branched_instance_feature.additional_properties.name",
    "rcsb_branched_instance_feature.additional_properties.values",
    "rcsb_branched_instance_feature_summary.count",
    "rcsb_branched_instance_feature_summary.coverage",
    "rcsb_branched_instance_feature_summary.maximum_length",
    "rcsb_branched_instance_feature_summary.maximum_value",
    "rcsb_branched_instance_feature_summary.minimum_length",
    "rcsb_branched_instance_feature_summary.minimum_value",
    "rcsb_branched_instance_feature_summary.type",
    "rcsb_branched_struct_conn.connect_type",
    "rcsb_branched_struct_conn.description",
    "rcsb_branched_struct_conn.dist_value",
    "rcsb_branched_struct_conn.id",
    "rcsb_branched_struct_conn.ordinal_id",
    "rcsb_branched_struct_conn.role",
    "rcsb_branched_struct_conn.value_order",
    "rcsb_branched_struct_conn.connect_target.auth_asym_id",
    "rcsb_branched_struct_conn.connect_target.auth_seq_id",
    "rcsb_branched_struct_conn.connect_target.label_alt_id",
    "rcsb_branched_struct_conn.connect_target.label_asym_id",
    "rcsb_branched_struct_conn.connect_target.label_atom_id",
    "rcsb_branched_struct_conn.connect_target.label_comp_id",
    "rcsb_branched_struct_conn.connect_target.label_seq_id",
    "rcsb_branched_struct_conn.connect_target.symmetry",
    "rcsb_branched_struct_conn.connect_partner.label_alt_id",
    "rcsb_branched_struct_conn.connect_partner.label_asym_id",
    "rcsb_branched_struct_conn.connect_partner.label_atom_id",
    "rcsb_branched_struct_conn.connect_partner.label_comp_id",
    "rcsb_branched_struct_conn.connect_partner.label_seq_id",
    "rcsb_branched_struct_conn.connect_partner.symmetry",
    "rcsb_ligand_neighbors.alt_id",
    "rcsb_ligand_neighbors.atom_id",
    "rcsb_ligand_neighbors.auth_seq_id",
    "rcsb_ligand_neighbors.comp_id",
    "rcsb_ligand_neighbors.distance",
    "rcsb_ligand_neighbors.ligand_alt_id",
    "rcsb_ligand_neighbors.ligand_asym_id",
    "rcsb_ligand_neighbors.ligand_atom_id",
    "rcsb_ligand_neighbors.ligand_comp_id",
    "rcsb_ligand_neighbors.ligand_entity_id",
    "rcsb_ligand_neighbors.ligand_is_bound",
    "rcsb_ligand_neighbors.ligand_model_id",
    "rcsb_ligand_neighbors.seq_id",
    "rcsb_id",
    "rcsb_latest_revision.major_revision",
    "rcsb_latest_revision.minor_revision",
    "rcsb_latest_revision.revision_date",
    "pdbx_entity_branch.rcsb_branched_component_count",
    "pdbx_entity_branch.type",
    "pdbx_entity_branch_descriptor.descriptor",
    "pdbx_entity_branch_descriptor.program",
    "pdbx_entity_branch_descriptor.program_version",
    "pdbx_entity_branch_descriptor.type",
    "rcsb_branched_entity.details",
    "rcsb_branched_entity.formula_weight",
    "rcsb_branched_entity.pdbx_description",
    "rcsb_branched_entity.pdbx_number_of_molecules",
    "rcsb_branched_entity_annotation.annotation_id",
    "rcsb_branched_entity_annotation.assignment_version",
    "rcsb_branched_entity_annotation.description",
    "rcsb_branched_entity_annotation.name",
    "rcsb_branched_entity_annotation.provenance_source",
    "rcsb_branched_entity_annotation.type",
    "rcsb_branched_entity_annotation.annotation_lineage.depth",
    "rcsb_branched_entity_annotation.annotation_lineage.id",
    "rcsb_branched_entity_annotation.annotation_lineage.name",
    "rcsb_branched_entity_container_identifiers.asym_ids",
    "rcsb_branched_entity_container_identifiers.auth_asym_ids",
    "rcsb_branched_entity_container_identifiers.chem_comp_monomers",
    "rcsb_branched_entity_container_identifiers.entity_id",
    "rcsb_branched_entity_container_identifiers.entry_id",
    "rcsb_branched_entity_container_identifiers.prd_id",
    "rcsb_branched_entity_container_identifiers.rcsb_id",
    "rcsb_branched_entity_feature.assignment_version",
    "rcsb_branched_entity_feature.description",
    "rcsb_branched_entity_feature.feature_id",
    "rcsb_branched_entity_feature.name",
    "rcsb_branched_entity_feature.provenance_source",
    "rcsb_branched_entity_feature.reference_scheme",
    "rcsb_branched_entity_feature.type",
    "rcsb_branched_entity_feature.feature_positions.beg_comp_id",
    "rcsb_branched_entity_feature.feature_positions.beg_seq_id",
    "rcsb_branched_entity_feature.feature_positions.end_seq_id",
    "rcsb_branched_entity_feature.feature_positions.value",
    "rcsb_branched_entity_feature.additional_properties.name",
    "rcsb_branched_entity_feature.additional_properties.values",
    "rcsb_branched_entity_feature_summary.count",
    "rcsb_branched_entity_feature_summary.coverage",
    "rcsb_branched_entity_feature_summary.maximum_length",
    "rcsb_branched_entity_feature_summary.maximum_value",
    "rcsb_branched_entity_feature_summary.minimum_length",
    "rcsb_branched_entity_feature_summary.minimum_value",
    "rcsb_branched_entity_feature_summary.type",
    "rcsb_branched_entity_keywords.text",
    "rcsb_branched_entity_name_com.name",
    "rcsb_branched_entity_name_sys.name",
    "rcsb_branched_entity_name_sys.system",
    "audit_author.identifier_ORCID",
    "audit_author.name",
    "audit_author.pdbx_ordinal",
    "cell.Z_PDB",
    "cell.angle_alpha",
    "cell.angle_beta",
    "cell.angle_gamma",
    "cell.formula_units_Z",
    "cell.length_a",
    "cell.length_b",
    "cell.length_c",
    "cell.pdbx_unique_axis",
    "cell.volume",
    "citation.book_id_ISBN",
    "citation.book_publisher",
    "citation.book_publisher_city",
    "citation.book_title",
    "citation.coordinate_linkage",
    "citation.country",
    "citation.id",
    "citation.journal_abbrev",
    "citation.journal_id_ASTM",
    "citation.journal_id_CSD",
    "citation.journal_id_ISSN",
    "citation.journal_issue",
    "citation.journal_volume",
    "citation.language",
    "citation.page_first",
    "citation.page_last",
    "citation.pdbx_database_id_DOI",
    "citation.pdbx_database_id_PubMed",
    "citation.rcsb_authors",
    "citation.rcsb_is_primary",
    "citation.rcsb_journal_abbrev",
    "citation.title",
    "citation.unpublished_flag",
    "citation.year",
    "diffrn.ambient_pressure",
    "diffrn.ambient_temp",
    "diffrn.ambient_temp_details",
    "diffrn.crystal_id",
    "diffrn.crystal_support",
    "diffrn.details",
    "diffrn.id",
    "diffrn.pdbx_serial_crystal_experiment",
    "diffrn_detector.details",
    "diffrn_detector.detector",
    "diffrn_detector.diffrn_id",
    "diffrn_detector.pdbx_collection_date",
    "diffrn_detector.pdbx_frequency",
    "diffrn_detector.type",
    "diffrn_radiation.collimation",
    "diffrn_radiation.diffrn_id",
    "diffrn_radiation.monochromator",
    "diffrn_radiation.pdbx_diffrn_protocol",
    "diffrn_radiation.pdbx_monochromatic_or_laue_m_l",
    "diffrn_radiation.pdbx_scattering_type",
    "diffrn_radiation.pdbx_wavelength",
    "diffrn_radiation.pdbx_wavelength_list",
    "diffrn_radiation.type",
    "diffrn_radiation.wavelength_id",
    "diffrn_source.details",
    "diffrn_source.diffrn_id",
    "diffrn_source.pdbx_synchrotron_beamline",
    "diffrn_source.pdbx_synchrotron_site",
    "diffrn_source.pdbx_wavelength",
    "diffrn_source.pdbx_wavelength_list",
    "diffrn_source.source",
    "diffrn_source.type",
    "em_2d_crystal_entity.angle_gamma",
    "em_2d_crystal_entity.c_sampling_length",
    "em_2d_crystal_entity.id",
    "em_2d_crystal_entity.image_processing_id",
    "em_2d_crystal_entity.length_a",
    "em_2d_crystal_entity.length_b",
    "em_2d_crystal_entity.length_c",
    "em_2d_crystal_entity.space_group_name_H_M",
    "em_3d_crystal_entity.angle_alpha",
    "em_3d_crystal_entity.angle_beta",
    "em_3d_crystal_entity.angle_gamma",
    "em_3d_crystal_entity.id",
    "em_3d_crystal_entity.image_processing_id",
    "em_3d_crystal_entity.length_a",
    "em_3d_crystal_entity.length_b",
    "em_3d_crystal_entity.length_c",
    "em_3d_crystal_entity.space_group_name",
    "em_3d_crystal_entity.space_group_num",
    "em_3d_fitting.details",
    "em_3d_fitting.id",
    "em_3d_fitting.method",
    "em_3d_fitting.overall_b_value",
    "em_3d_fitting.ref_protocol",
    "em_3d_fitting.ref_space",
    "em_3d_fitting.target_criteria",
    "em_3d_fitting_list.3d_fitting_id",
    "em_3d_fitting_list.details",
    "em_3d_fitting_list.id",
    "em_3d_fitting_list.pdb_chain_id",
    "em_3d_fitting_list.pdb_chain_residue_range",
    "em_3d_fitting_list.pdb_entry_id",
    "em_3d_reconstruction.actual_pixel_size",
    "em_3d_reconstruction.algorithm",
    "em_3d_reconstruction.details",
    "em_3d_reconstruction.id",
    "em_3d_reconstruction.image_processing_id",
    "em_3d_reconstruction.magnification_calibration",
    "em_3d_reconstruction.method",
    "em_3d_reconstruction.nominal_pixel_size",
    "em_3d_reconstruction.num_class_averages",
    "em_3d_reconstruction.num_particles",
    "em_3d_reconstruction.refinement_type",
    "em_3d_reconstruction.resolution",
    "em_3d_reconstruction.resolution_method",
    "em_3d_reconstruction.symmetry_type",
    "em_ctf_correction.details",
    "em_ctf_correction.em_image_processing_id",
    "em_ctf_correction.id",
    "em_ctf_correction.type",
    "em_diffraction.camera_length",
    "em_diffraction.id",
    "em_diffraction.imaging_id",
    "em_diffraction.tilt_angle_list",
    "em_diffraction_shell.em_diffraction_stats_id",
    "em_diffraction_shell.fourier_space_coverage",
    "em_diffraction_shell.high_resolution",
    "em_diffraction_shell.id",
    "em_diffraction_shell.low_resolution",
    "em_diffraction_shell.multiplicity",
    "em_diffraction_shell.num_structure_factors",
    "em_diffraction_shell.phase_residual",
    "em_diffraction_stats.details",
    "em_diffraction_stats.fourier_space_coverage",
    "em_diffraction_stats.high_resolution",
    "em_diffraction_stats.id",
    "em_diffraction_stats.image_processing_id",
    "em_diffraction_stats.num_intensities_measured",
    "em_diffraction_stats.num_structure_factors",
    "em_diffraction_stats.overall_phase_error",
    "em_diffraction_stats.overall_phase_residual",
    "em_diffraction_stats.phase_error_rejection_criteria",
    "em_diffraction_stats.r_merge",
    "em_diffraction_stats.r_sym",
    "em_embedding.details",
    "em_embedding.id",
    "em_embedding.material",
    "em_embedding.specimen_id",
    "em_entity_assembly.details",
    "em_entity_assembly.entity_id_list",
    "em_entity_assembly.id",
    "em_entity_assembly.name",
    "em_entity_assembly.oligomeric_details",
    "em_entity_assembly.parent_id",
    "em_entity_assembly.source",
    "em_entity_assembly.synonym",
    "em_entity_assembly.type",
    "em_experiment.aggregation_state",
    "em_experiment.entity_assembly_id",
    "em_experiment.id",
    "em_experiment.reconstruction_method",
    "em_helical_entity.angular_rotation_per_subunit",
    "em_helical_entity.axial_rise_per_subunit",
    "em_helical_entity.axial_symmetry",
    "em_helical_entity.details",
    "em_helical_entity.id",
    "em_helical_entity.image_processing_id",
    "em_image_recording.average_exposure_time",
    "em_image_recording.avg_electron_dose_per_image",
    "em_image_recording.details",
    "em_image_recording.detector_mode",
    "em_image_recording.film_or_detector_model",
    "em_image_recording.id",
    "em_image_recording.imaging_id",
    "em_image_recording.num_diffraction_images",
    "em_image_recording.num_grids_imaged",
    "em_image_recording.num_real_images",
    "em_imaging.accelerating_voltage",
    "em_imaging.alignment_procedure",
    "em_imaging.astigmatism",
    "em_imaging.c2_aperture_diameter",
    "em_imaging.calibrated_defocus_max",
    "em_imaging.calibrated_defocus_min",
    "em_imaging.calibrated_magnification",
    "em_imaging.cryogen",
    "em_imaging.date",
    "em_imaging.details",
    "em_imaging.detector_distance",
    "em_imaging.electron_beam_tilt_params",
    "em_imaging.electron_source",
    "em_imaging.id",
    "em_imaging.illumination_mode",
    "em_imaging.microscope_model",
    "em_imaging.mode",
    "em_imaging.nominal_cs",
    "em_imaging.nominal_defocus_max",
    "em_imaging.nominal_defocus_min",
    "em_imaging.nominal_magnification",
    "em_imaging.recording_temperature_maximum",
    "em_imaging.recording_temperature_minimum",
    "em_imaging.residual_tilt",
    "em_imaging.specimen_holder_model",
    "em_imaging.specimen_holder_type",
    "em_imaging.specimen_id",
    "em_imaging.temperature",
    "em_imaging.tilt_angle_max",
    "em_imaging.tilt_angle_min",
    "em_particle_selection.details",
    "em_particle_selection.id",
    "em_particle_selection.image_processing_id",
    "em_particle_selection.num_particles_selected",
    "em_single_particle_entity.id",
    "em_single_particle_entity.image_processing_id",
    "em_single_particle_entity.point_symmetry",
    "em_software.category",
    "em_software.details",
    "em_software.fitting_id",
    "em_software.id",
    "em_software.image_processing_id",
    "em_software.imaging_id",
    "em_software.name",
    "em_software.version",
    "em_specimen.concentration",
    "em_specimen.details",
    "em_specimen.embedding_applied",
    "em_specimen.experiment_id",
    "em_specimen.id",
    "em_specimen.shadowing_applied",
    "em_specimen.staining_applied",
    "em_specimen.vitrification_applied",
    "em_staining.details",
    "em_staining.id",
    "em_staining.material",
    "em_staining.specimen_id",
    "em_staining.type",
    "em_vitrification.chamber_temperature",
    "em_vitrification.cryogen_name",
    "em_vitrification.details",
    "em_vitrification.humidity",
    "em_vitrification.id",
    "em_vitrification.instrument",
    "em_vitrification.method",
    "em_vitrification.specimen_id",
    "em_vitrification.temp",
    "em_vitrification.time_resolved_state",
    "entry.id",
    "exptl.crystals_number",
    "exptl.details",
    "exptl.method",
    "exptl.method_details",
    "exptl_crystal.colour",
    "exptl_crystal.density_Matthews",
    "exptl_crystal.density_meas",
    "exptl_crystal.density_percent_sol",
    "exptl_crystal.description",
    "exptl_crystal.id",
    "exptl_crystal.pdbx_mosaicity",
    "exptl_crystal.pdbx_mosaicity_esd",
    "exptl_crystal.preparation",
    "exptl_crystal_grow.crystal_id",
    "exptl_crystal_grow.details",
    "exptl_crystal_grow.method",
    "exptl_crystal_grow.pH",
    "exptl_crystal_grow.pdbx_details",
    "exptl_crystal_grow.pdbx_pH_range",
    "exptl_crystal_grow.temp",
    "exptl_crystal_grow.temp_details",
    "pdbx_SG_project.full_name_of_center",
    "pdbx_SG_project.id",
    "pdbx_SG_project.initial_of_center",
    "pdbx_SG_project.project_name",
    "pdbx_audit_revision_category.category",
    "pdbx_audit_revision_category.data_content_type",
    "pdbx_audit_revision_category.ordinal",
    "pdbx_audit_revision_category.revision_ordinal",
    "pdbx_audit_revision_details.data_content_type",
    "pdbx_audit_revision_details.description",
    "pdbx_audit_revision_details.details",
    "pdbx_audit_revision_details.ordinal",
    "pdbx_audit_revision_details.provider",
    "pdbx_audit_revision_details.revision_ordinal",
    "pdbx_audit_revision_details.type",
    "pdbx_audit_revision_group.data_content_type",
    "pdbx_audit_revision_group.group",
    "pdbx_audit_revision_group.ordinal",
    "pdbx_audit_revision_group.revision_ordinal",
    "pdbx_audit_revision_history.data_content_type",
    "pdbx_audit_revision_history.major_revision",
    "pdbx_audit_revision_history.minor_revision",
    "pdbx_audit_revision_history.ordinal",
    "pdbx_audit_revision_history.revision_date",
    "pdbx_audit_revision_item.data_content_type",
    "pdbx_audit_revision_item.item",
    "pdbx_audit_revision_item.ordinal",
    "pdbx_audit_revision_item.revision_ordinal",
    "pdbx_audit_support.country",
    "pdbx_audit_support.funding_organization",
    "pdbx_audit_support.grant_number",
    "pdbx_audit_support.ordinal",
    "pdbx_database_PDB_obs_spr.date",
    "pdbx_database_PDB_obs_spr.details",
    "pdbx_database_PDB_obs_spr.id",
    "pdbx_database_PDB_obs_spr.pdb_id",
    "pdbx_database_PDB_obs_spr.replace_pdb_id",
    "pdbx_database_related.content_type",
    "pdbx_database_related.db_id",
    "pdbx_database_related.db_name",
    "pdbx_database_related.details",
    "pdbx_database_status.SG_entry",
    "pdbx_database_status.deposit_site",
    "pdbx_database_status.methods_development_category",
    "pdbx_database_status.pdb_format_compatible",
    "pdbx_database_status.process_site",
    "pdbx_database_status.recvd_initial_deposition_date",
    "pdbx_database_status.status_code",
    "pdbx_database_status.status_code_cs",
    "pdbx_database_status.status_code_mr",
    "pdbx_database_status.status_code_sf",
    "pdbx_deposit_group.group_description",
    "pdbx_deposit_group.group_id",
    "pdbx_deposit_group.group_title",
    "pdbx_deposit_group.group_type",
    "pdbx_molecule_features.class",
    "pdbx_molecule_features.details",
    "pdbx_molecule_features.name",
    "pdbx_molecule_features.prd_id",
    "pdbx_molecule_features.type",
    "pdbx_nmr_details.text",
    "pdbx_nmr_ensemble.average_constraint_violations_per_residue",
    "pdbx_nmr_ensemble.average_constraints_per_residue",
    "pdbx_nmr_ensemble.average_distance_constraint_violation",
    "pdbx_nmr_ensemble.average_torsion_angle_constraint_violation",
    "pdbx_nmr_ensemble.conformer_selection_criteria",
    "pdbx_nmr_ensemble.conformers_calculated_total_number",
    "pdbx_nmr_ensemble.conformers_submitted_total_number",
    "pdbx_nmr_ensemble.distance_constraint_violation_method",
    "pdbx_nmr_ensemble.maximum_distance_constraint_violation",
    "pdbx_nmr_ensemble.maximum_lower_distance_constraint_violation",
    "pdbx_nmr_ensemble.maximum_torsion_angle_constraint_violation",
    "pdbx_nmr_ensemble.maximum_upper_distance_constraint_violation",
    "pdbx_nmr_ensemble.representative_conformer",
    "pdbx_nmr_ensemble.torsion_angle_constraint_violation_method",
    "pdbx_nmr_exptl.conditions_id",
    "pdbx_nmr_exptl.experiment_id",
    "pdbx_nmr_exptl.sample_state",
    "pdbx_nmr_exptl.solution_id",
    "pdbx_nmr_exptl.spectrometer_id",
    "pdbx_nmr_exptl.type",
    "pdbx_nmr_exptl_sample_conditions.conditions_id",
    "pdbx_nmr_exptl_sample_conditions.details",
    "pdbx_nmr_exptl_sample_conditions.ionic_strength",
    "pdbx_nmr_exptl_sample_conditions.ionic_strength_err",
    "pdbx_nmr_exptl_sample_conditions.ionic_strength_units",
    "pdbx_nmr_exptl_sample_conditions.label",
    "pdbx_nmr_exptl_sample_conditions.pH",
    "pdbx_nmr_exptl_sample_conditions.pH_err",
    "pdbx_nmr_exptl_sample_conditions.pH_units",
    "pdbx_nmr_exptl_sample_conditions.pressure",
    "pdbx_nmr_exptl_sample_conditions.pressure_err",
    "pdbx_nmr_exptl_sample_conditions.pressure_units",
    "pdbx_nmr_exptl_sample_conditions.temperature",
    "pdbx_nmr_exptl_sample_conditions.temperature_err",
    "pdbx_nmr_exptl_sample_conditions.temperature_units",
    "pdbx_nmr_refine.details",
    "pdbx_nmr_refine.method",
    "pdbx_nmr_refine.software_ordinal",
    "pdbx_nmr_representative.conformer_id",
    "pdbx_nmr_representative.selection_criteria",
    "pdbx_nmr_sample_details.contents",
    "pdbx_nmr_sample_details.details",
    "pdbx_nmr_sample_details.label",
    "pdbx_nmr_sample_details.solution_id",
    "pdbx_nmr_sample_details.solvent_system",
    "pdbx_nmr_sample_details.type",
    "pdbx_nmr_software.authors",
    "pdbx_nmr_software.classification",
    "pdbx_nmr_software.name",
    "pdbx_nmr_software.ordinal",
    "pdbx_nmr_software.version",
    "pdbx_nmr_spectrometer.details",
    "pdbx_nmr_spectrometer.field_strength",
    "pdbx_nmr_spectrometer.manufacturer",
    "pdbx_nmr_spectrometer.model",
    "pdbx_nmr_spectrometer.spectrometer_id",
    "pdbx_nmr_spectrometer.type",
    "pdbx_related_exp_data_set.data_reference",
    "pdbx_related_exp_data_set.data_set_type",
    "pdbx_related_exp_data_set.details",
    "pdbx_related_exp_data_set.metadata_reference",
    "pdbx_serial_crystallography_data_reduction.crystal_hits",
    "pdbx_serial_crystallography_data_reduction.diffrn_id",
    "pdbx_serial_crystallography_data_reduction.droplet_hits",
    "pdbx_serial_crystallography_data_reduction.frame_hits",
    "pdbx_serial_crystallography_data_reduction.frames_failed_index",
    "pdbx_serial_crystallography_data_reduction.frames_indexed",
    "pdbx_serial_crystallography_data_reduction.frames_total",
    "pdbx_serial_crystallography_data_reduction.lattices_indexed",
    "pdbx_serial_crystallography_data_reduction.xfel_pulse_events",
    "pdbx_serial_crystallography_data_reduction.xfel_run_numbers",
    "pdbx_serial_crystallography_measurement.collection_time_total",
    "pdbx_serial_crystallography_measurement.collimation",
    "pdbx_serial_crystallography_measurement.diffrn_id",
    "pdbx_serial_crystallography_measurement.focal_spot_size",
    "pdbx_serial_crystallography_measurement.photons_per_pulse",
    "pdbx_serial_crystallography_measurement.pulse_duration",
    "pdbx_serial_crystallography_measurement.pulse_energy",
    "pdbx_serial_crystallography_measurement.pulse_photon_energy",
    "pdbx_serial_crystallography_measurement.source_distance",
    "pdbx_serial_crystallography_measurement.source_size",
    "pdbx_serial_crystallography_measurement.xfel_pulse_repetition_rate",
    "pdbx_serial_crystallography_sample_delivery.description",
    "pdbx_serial_crystallography_sample_delivery.diffrn_id",
    "pdbx_serial_crystallography_sample_delivery.method",
    "pdbx_serial_crystallography_sample_delivery_fixed_target.crystals_per_unit",
    "pdbx_serial_crystallography_sample_delivery_fixed_target.description",
    "pdbx_serial_crystallography_sample_delivery_fixed_target.details",
    "pdbx_serial_crystallography_sample_delivery_fixed_target.diffrn_id",
    "pdbx_serial_crystallography_sample_delivery_fixed_target.motion_control",
    "pdbx_serial_crystallography_sample_delivery_fixed_target.sample_dehydration_prevention",
    "pdbx_serial_crystallography_sample_delivery_fixed_target.sample_holding",
    "pdbx_serial_crystallography_sample_delivery_fixed_target.sample_solvent",
    "pdbx_serial_crystallography_sample_delivery_fixed_target.sample_unit_size",
    "pdbx_serial_crystallography_sample_delivery_fixed_target.support_base",
    "pdbx_serial_crystallography_sample_delivery_fixed_target.velocity_horizontal",
    "pdbx_serial_crystallography_sample_delivery_fixed_target.velocity_vertical",
    "pdbx_serial_crystallography_sample_delivery_injection.carrier_solvent",
    "pdbx_serial_crystallography_sample_delivery_injection.crystal_concentration",
    "pdbx_serial_crystallography_sample_delivery_injection.description",
    "pdbx_serial_crystallography_sample_delivery_injection.diffrn_id",
    "pdbx_serial_crystallography_sample_delivery_injection.filter_size",
    "pdbx_serial_crystallography_sample_delivery_injection.flow_rate",
    "pdbx_serial_crystallography_sample_delivery_injection.injector_diameter",
    "pdbx_serial_crystallography_sample_delivery_injection.injector_nozzle",
    "pdbx_serial_crystallography_sample_delivery_injection.injector_pressure",
    "pdbx_serial_crystallography_sample_delivery_injection.injector_temperature",
    "pdbx_serial_crystallography_sample_delivery_injection.jet_diameter",
    "pdbx_serial_crystallography_sample_delivery_injection.power_by",
    "pdbx_serial_crystallography_sample_delivery_injection.preparation",
    "pdbx_soln_scatter.buffer_name",
    "pdbx_soln_scatter.concentration_range",
    "pdbx_soln_scatter.data_analysis_software_list",
    "pdbx_soln_scatter.data_reduction_software_list",
    "pdbx_soln_scatter.detector_specific",
    "pdbx_soln_scatter.detector_type",
    "pdbx_soln_scatter.id",
    "pdbx_soln_scatter.max_mean_cross_sectional_radii_gyration",
    "pdbx_soln_scatter.max_mean_cross_sectional_radii_gyration_esd",
    "pdbx_soln_scatter.mean_guiner_radius",
    "pdbx_soln_scatter.mean_guiner_radius_esd",
    "pdbx_soln_scatter.min_mean_cross_sectional_radii_gyration",
    "pdbx_soln_scatter.min_mean_cross_sectional_radii_gyration_esd",
    "pdbx_soln_scatter.num_time_frames",
    "pdbx_soln_scatter.protein_length",
    "pdbx_soln_scatter.sample_pH",
    "pdbx_soln_scatter.source_beamline",
    "pdbx_soln_scatter.source_beamline_instrument",
    "pdbx_soln_scatter.source_class",
    "pdbx_soln_scatter.source_type",
    "pdbx_soln_scatter.temperature",
    "pdbx_soln_scatter.type",
    "pdbx_soln_scatter_model.conformer_selection_criteria",
    "pdbx_soln_scatter_model.details",
    "pdbx_soln_scatter_model.entry_fitting_list",
    "pdbx_soln_scatter_model.id",
    "pdbx_soln_scatter_model.method",
    "pdbx_soln_scatter_model.num_conformers_calculated",
    "pdbx_soln_scatter_model.num_conformers_submitted",
    "pdbx_soln_scatter_model.representative_conformer",
    "pdbx_soln_scatter_model.scatter_id",
    "pdbx_soln_scatter_model.software_author_list",
    "pdbx_soln_scatter_model.software_list",
    "pdbx_vrpt_summary.B_factor_type",
    "pdbx_vrpt_summary.Babinet_b",
    "pdbx_vrpt_summary.Babinet_k",
    "pdbx_vrpt_summary.CA_ONLY",
    "pdbx_vrpt_summary.DCC_R",
    "pdbx_vrpt_summary.DCC_Rfree",
    "pdbx_vrpt_summary.DCC_refinement_program",
    "pdbx_vrpt_summary.EDS_R",
    "pdbx_vrpt_summary.EDS_resolution",
    "pdbx_vrpt_summary.EDS_resolution_low",
    "pdbx_vrpt_summary.EMDB_deposition_date",
    "pdbx_vrpt_summary.EMDB_resolution",
    "pdbx_vrpt_summary.Fo_Fc_correlation",
    "pdbx_vrpt_summary.I_over_sigma",
    "pdbx_vrpt_summary.PDB_R",
    "pdbx_vrpt_summary.PDB_Rfree",
    "pdbx_vrpt_summary.PDB_deposition_date",
    "pdbx_vrpt_summary.PDB_resolution",
    "pdbx_vrpt_summary.PDB_resolution_low",
    "pdbx_vrpt_summary.PDB_revision_date",
    "pdbx_vrpt_summary.PDB_revision_number",
    "pdbx_vrpt_summary.RNA_suiteness",
    "pdbx_vrpt_summary.Wilson_B_aniso",
    "pdbx_vrpt_summary.Wilson_B_estimate",
    "pdbx_vrpt_summary.absolute_percentile_DCC_Rfree",
    "pdbx_vrpt_summary.absolute_percentile_RNA_suiteness",
    "pdbx_vrpt_summary.absolute_percentile_clashscore",
    "pdbx_vrpt_summary.absolute_percentile_percent_RSRZ_outliers",
    "pdbx_vrpt_summary.absolute_percentile_percent_ramachandran_outliers",
    "pdbx_vrpt_summary.absolute_percentile_percent_rotamer_outliers",
    "pdbx_vrpt_summary.acentric_outliers",
    "pdbx_vrpt_summary.angles_RMSZ",
    "pdbx_vrpt_summary.atom_inclusion_all_atoms",
    "pdbx_vrpt_summary.atom_inclusion_backbone",
    "pdbx_vrpt_summary.attempted_validation_steps",
    "pdbx_vrpt_summary.author_provided_fsc_resolution_by_cutoff_halfbit",
    "pdbx_vrpt_summary.author_provided_fsc_resolution_by_cutoff_onebit",
    "pdbx_vrpt_summary.author_provided_fsc_resolution_by_cutoff_pt_143",
    "pdbx_vrpt_summary.author_provided_fsc_resolution_by_cutoff_pt_333",
    "pdbx_vrpt_summary.author_provided_fsc_resolution_by_cutoff_pt_5",
    "pdbx_vrpt_summary.author_provided_fsc_resolution_by_cutoff_threesigma",
    "pdbx_vrpt_summary.bonds_RMSZ",
    "pdbx_vrpt_summary.bulk_solvent_b",
    "pdbx_vrpt_summary.bulk_solvent_k",
    "pdbx_vrpt_summary.calculated_fsc_resolution_by_cutoff_halfbit",
    "pdbx_vrpt_summary.calculated_fsc_resolution_by_cutoff_onebit",
    "pdbx_vrpt_summary.calculated_fsc_resolution_by_cutoff_pt_143",
    "pdbx_vrpt_summary.calculated_fsc_resolution_by_cutoff_pt_333",
    "pdbx_vrpt_summary.calculated_fsc_resolution_by_cutoff_pt_5",
    "pdbx_vrpt_summary.calculated_fsc_resolution_by_cutoff_threesigma",
    "pdbx_vrpt_summary.ccp4version",
    "pdbx_vrpt_summary.centric_outliers",
    "pdbx_vrpt_summary.chemical_shift_completeness",
    "pdbx_vrpt_summary.chemical_shift_completeness_full_length",
    "pdbx_vrpt_summary.chemical_shifts_input_filename",
    "pdbx_vrpt_summary.clashscore",
    "pdbx_vrpt_summary.clashscore_full_length",
    "pdbx_vrpt_summary.contour_level_primary_map",
    "pdbx_vrpt_summary.coordinates_input_filename",
    "pdbx_vrpt_summary.cyrange_error",
    "pdbx_vrpt_summary.cyrange_number_of_domains",
    "pdbx_vrpt_summary.cyrange_version",
    "pdbx_vrpt_summary.data_anisotropy",
    "pdbx_vrpt_summary.data_completeness",
    "pdbx_vrpt_summary.emdb_id",
    "pdbx_vrpt_summary.high_resol_relative_percentile_DCC_Rfree",
    "pdbx_vrpt_summary.high_resol_relative_percentile_RNA_suiteness",
    "pdbx_vrpt_summary.high_resol_relative_percentile_clashscore",
    "pdbx_vrpt_summary.high_resol_relative_percentile_percent_RSRZ_outliers",
    "pdbx_vrpt_summary.high_resol_relative_percentile_percent_ramachandran_outliers",
    "pdbx_vrpt_summary.high_resol_relative_percentile_percent_rotamer_outliers",
    "pdbx_vrpt_summary.ligands_for_buster_report",
    "pdbx_vrpt_summary.low_resol_relative_percentile_DCC_Rfree",
    "pdbx_vrpt_summary.low_resol_relative_percentile_RNA_suiteness",
    "pdbx_vrpt_summary.low_resol_relative_percentile_clashscore",
    "pdbx_vrpt_summary.low_resol_relative_percentile_percent_RSRZ_outliers",
    "pdbx_vrpt_summary.low_resol_relative_percentile_percent_ramachandran_outliers",
    "pdbx_vrpt_summary.low_resol_relative_percentile_percent_rotamer_outliers",
    "pdbx_vrpt_summary.medoid_model",
    "pdbx_vrpt_summary.nmr_models_consistency_flag",
    "pdbx_vrpt_summary.nmrclust_error",
    "pdbx_vrpt_summary.nmrclust_number_of_clusters",
    "pdbx_vrpt_summary.nmrclust_number_of_models",
    "pdbx_vrpt_summary.nmrclust_number_of_outliers",
    "pdbx_vrpt_summary.nmrclust_representative_model",
    "pdbx_vrpt_summary.nmrclust_version",
    "pdbx_vrpt_summary.no_ligands_for_buster_report",
    "pdbx_vrpt_summary.no_ligands_for_mogul",
    "pdbx_vrpt_summary.no_percentile_property",
    "pdbx_vrpt_summary.num_H_reduce",
    "pdbx_vrpt_summary.num_PDBids_absolute_percentile_DCC_Rfree",
    "pdbx_vrpt_summary.num_PDBids_absolute_percentile_RNA_suiteness",
    "pdbx_vrpt_summary.num_PDBids_absolute_percentile_clashscore",
    "pdbx_vrpt_summary.num_PDBids_absolute_percentile_percent_RSRZ_outliers",
    "pdbx_vrpt_summary.num_PDBids_absolute_percentile_percent_ramachandran_outliers",
    "pdbx_vrpt_summary.num_PDBids_absolute_percentile_percent_rotamer_outliers",
    "pdbx_vrpt_summary.num_PDBids_relative_percentile_DCC_Rfree",
    "pdbx_vrpt_summary.num_PDBids_relative_percentile_RNA_suiteness",
    "pdbx_vrpt_summary.num_PDBids_relative_percentile_clashscore",
    "pdbx_vrpt_summary.num_PDBids_relative_percentile_percent_RSRZ_outliers",
    "pdbx_vrpt_summary.num_PDBids_relative_percentile_percent_ramachandran_outliers",
    "pdbx_vrpt_summary.num_PDBids_relative_percentile_percent_rotamer_outliers",
    "pdbx_vrpt_summary.num_angles_RMSZ",
    "pdbx_vrpt_summary.num_bonds_RMSZ",
    "pdbx_vrpt_summary.num_free_reflections",
    "pdbx_vrpt_summary.num_miller_indices",
    "pdbx_vrpt_summary.panav_version",
    "pdbx_vrpt_summary.percent_RSRZ_outliers",
    "pdbx_vrpt_summary.percent_free_reflections",
    "pdbx_vrpt_summary.percent_ramachandran_outliers",
    "pdbx_vrpt_summary.percent_ramachandran_outliers_full_length",
    "pdbx_vrpt_summary.percent_rotamer_outliers",
    "pdbx_vrpt_summary.percent_rotamer_outliers_full_length",
    "pdbx_vrpt_summary.percentilebins",
    "pdbx_vrpt_summary.protein_DNA_RNA_entities",
    "pdbx_vrpt_summary.rci_version",
    "pdbx_vrpt_summary.reflections_input_filename",
    "pdbx_vrpt_summary.refmac_version",
    "pdbx_vrpt_summary.relative_percentile_DCC_Rfree",
    "pdbx_vrpt_summary.relative_percentile_RNA_suiteness",
    "pdbx_vrpt_summary.relative_percentile_clashscore",
    "pdbx_vrpt_summary.relative_percentile_percent_RSRZ_outliers",
    "pdbx_vrpt_summary.relative_percentile_percent_ramachandran_outliers",
    "pdbx_vrpt_summary.relative_percentile_percent_rotamer_outliers",
    "pdbx_vrpt_summary.report_creation_date",
    "pdbx_vrpt_summary.resol_high_from_reflectionsfile",
    "pdbx_vrpt_summary.resol_low_from_reflectionsfile",
    "pdbx_vrpt_summary.restypes_notchecked_for_bond_angle_geometry",
    "pdbx_vrpt_summary.shiftchecker_version",
    "pdbx_vrpt_summary.trans_NSC",
    "pdbx_vrpt_summary.twin_L",
    "pdbx_vrpt_summary.twin_L2",
    "pdbx_vrpt_summary.twin_fraction",
    "pdbx_vrpt_summary.xtriage_input_columns",
    "rcsb_accession_info.deposit_date",
    "rcsb_accession_info.has_released_experimental_data",
    "rcsb_accession_info.initial_release_date",
    "rcsb_accession_info.major_revision",
    "rcsb_accession_info.minor_revision",
    "rcsb_accession_info.revision_date",
    "rcsb_accession_info.status_code",
    "rcsb_entry_container_identifiers.assembly_ids",
    "rcsb_entry_container_identifiers.branched_entity_ids",
    "rcsb_entry_container_identifiers.emdb_ids",
    "rcsb_entry_container_identifiers.entity_ids",
    "rcsb_entry_container_identifiers.entry_id",
    "rcsb_entry_container_identifiers.model_ids",
    "rcsb_entry_container_identifiers.non_polymer_entity_ids",
    "rcsb_entry_container_identifiers.polymer_entity_ids",
    "rcsb_entry_container_identifiers.rcsb_id",
    "rcsb_entry_container_identifiers.related_emdb_ids",
    "rcsb_entry_container_identifiers.water_entity_ids",
    "rcsb_entry_container_identifiers.pubmed_id",
    "rcsb_entry_info.assembly_count",
    "rcsb_entry_info.branched_entity_count",
    "rcsb_entry_info.branched_molecular_weight_maximum",
    "rcsb_entry_info.branched_molecular_weight_minimum",
    "rcsb_entry_info.cis_peptide_count",
    "rcsb_entry_info.deposited_atom_count",
    "rcsb_entry_info.deposited_hydrogen_atom_count",
    "rcsb_entry_info.deposited_model_count",
    "rcsb_entry_info.deposited_modeled_polymer_monomer_count",
    "rcsb_entry_info.deposited_nonpolymer_entity_instance_count",
    "rcsb_entry_info.deposited_polymer_entity_instance_count",
    "rcsb_entry_info.deposited_polymer_monomer_count",
    "rcsb_entry_info.deposited_solvent_atom_count",
    "rcsb_entry_info.deposited_unmodeled_polymer_monomer_count",
    "rcsb_entry_info.diffrn_radiation_wavelength_maximum",
    "rcsb_entry_info.diffrn_radiation_wavelength_minimum",
    "rcsb_entry_info.disulfide_bond_count",
    "rcsb_entry_info.entity_count",
    "rcsb_entry_info.experimental_method",
    "rcsb_entry_info.experimental_method_count",
    "rcsb_entry_info.inter_mol_covalent_bond_count",
    "rcsb_entry_info.inter_mol_metalic_bond_count",
    "rcsb_entry_info.molecular_weight",
    "rcsb_entry_info.na_polymer_entity_types",
    "rcsb_entry_info.nonpolymer_bound_components",
    "rcsb_entry_info.nonpolymer_entity_count",
    "rcsb_entry_info.nonpolymer_molecular_weight_maximum",
    "rcsb_entry_info.nonpolymer_molecular_weight_minimum",
    "rcsb_entry_info.polymer_composition",
    "rcsb_entry_info.polymer_entity_count",
    "rcsb_entry_info.polymer_entity_count_DNA",
    "rcsb_entry_info.polymer_entity_count_RNA",
    "rcsb_entry_info.polymer_entity_count_nucleic_acid",
    "rcsb_entry_info.polymer_entity_count_nucleic_acid_hybrid",
    "rcsb_entry_info.polymer_entity_count_protein",
    "rcsb_entry_info.polymer_entity_taxonomy_count",
    "rcsb_entry_info.polymer_molecular_weight_maximum",
    "rcsb_entry_info.polymer_molecular_weight_minimum",
    "rcsb_entry_info.polymer_monomer_count_maximum",
    "rcsb_entry_info.polymer_monomer_count_minimum",
    "rcsb_entry_info.resolution_combined",
    "rcsb_entry_info.selected_polymer_entity_types",
    "rcsb_entry_info.software_programs_combined",
    "rcsb_entry_info.solvent_entity_count",
    "rcsb_entry_info.diffrn_resolution_high.provenance_source",
    "rcsb_entry_info.diffrn_resolution_high.value",
    "rcsb_primary_citation.book_id_ISBN",
    "rcsb_primary_citation.book_publisher",
    "rcsb_primary_citation.book_publisher_city",
    "rcsb_primary_citation.book_title",
    "rcsb_primary_citation.coordinate_linkage",
    "rcsb_primary_citation.country",
    "rcsb_primary_citation.id",
    "rcsb_primary_citation.journal_abbrev",
    "rcsb_primary_citation.journal_id_ASTM",
    "rcsb_primary_citation.journal_id_CSD",
    "rcsb_primary_citation.journal_id_ISSN",
    "rcsb_primary_citation.journal_issue",
    "rcsb_primary_citation.journal_volume",
    "rcsb_primary_citation.language",
    "rcsb_primary_citation.page_first",
    "rcsb_primary_citation.page_last",
    "rcsb_primary_citation.pdbx_database_id_DOI",
    "rcsb_primary_citation.pdbx_database_id_PubMed",
    "rcsb_primary_citation.rcsb_ORCID_identifiers",
    "rcsb_primary_citation.rcsb_authors",
    "rcsb_primary_citation.rcsb_journal_abbrev",
    "rcsb_primary_citation.title",
    "rcsb_primary_citation.year",
    "refine.B_iso_max",
    "refine.B_iso_mean",
    "refine.B_iso_min",
    "refine.aniso_B_1_1",
    "refine.aniso_B_1_2",
    "refine.aniso_B_1_3",
    "refine.aniso_B_2_2",
    "refine.aniso_B_2_3",
    "refine.aniso_B_3_3",
    "refine.correlation_coeff_Fo_to_Fc",
    "refine.correlation_coeff_Fo_to_Fc_free",
    "refine.details",
    "refine.ls_R_factor_R_free",
    "refine.ls_R_factor_R_free_error",
    "refine.ls_R_factor_R_free_error_details",
    "refine.ls_R_factor_R_work",
    "refine.ls_R_factor_all",
    "refine.ls_R_factor_obs",
    "refine.ls_d_res_high",
    "refine.ls_d_res_low",
    "refine.ls_matrix_type",
    "refine.ls_number_parameters",
    "refine.ls_number_reflns_R_free",
    "refine.ls_number_reflns_R_work",
    "refine.ls_number_reflns_all",
    "refine.ls_number_reflns_obs",
    "refine.ls_number_restraints",
    "refine.ls_percent_reflns_R_free",
    "refine.ls_percent_reflns_obs",
    "refine.ls_redundancy_reflns_all",
    "refine.ls_redundancy_reflns_obs",
    "refine.ls_wR_factor_R_free",
    "refine.ls_wR_factor_R_work",
    "refine.occupancy_max",
    "refine.occupancy_min",
    "refine.overall_FOM_free_R_set",
    "refine.overall_FOM_work_R_set",
    "refine.overall_SU_B",
    "refine.overall_SU_ML",
    "refine.overall_SU_R_Cruickshank_DPI",
    "refine.overall_SU_R_free",
    "refine.pdbx_R_Free_selection_details",
    "refine.pdbx_TLS_residual_ADP_flag",
    "refine.pdbx_average_fsc_free",
    "refine.pdbx_average_fsc_overall",
    "refine.pdbx_average_fsc_work",
    "refine.pdbx_data_cutoff_high_absF",
    "refine.pdbx_data_cutoff_high_rms_absF",
    "refine.pdbx_data_cutoff_low_absF",
    "refine.pdbx_diffrn_id",
    "refine.pdbx_isotropic_thermal_model",
    "refine.pdbx_ls_cross_valid_method",
    "refine.pdbx_ls_sigma_F",
    "refine.pdbx_ls_sigma_Fsqd",
    "refine.pdbx_ls_sigma_I",
    "refine.pdbx_method_to_determine_struct",
    "refine.pdbx_overall_ESU_R",
    "refine.pdbx_overall_ESU_R_Free",
    "refine.pdbx_overall_SU_R_Blow_DPI",
    "refine.pdbx_overall_SU_R_free_Blow_DPI",
    "refine.pdbx_overall_SU_R_free_Cruickshank_DPI",
    "refine.pdbx_overall_phase_error",
    "refine.pdbx_refine_id",
    "refine.pdbx_solvent_ion_probe_radii",
    "refine.pdbx_solvent_shrinkage_radii",
    "refine.pdbx_solvent_vdw_probe_radii",
    "refine.pdbx_starting_model",
    "refine.pdbx_stereochem_target_val_spec_case",
    "refine.pdbx_stereochemistry_target_values",
    "refine.solvent_model_details",
    "refine.solvent_model_param_bsol",
    "refine.solvent_model_param_ksol",
    "refine_analyze.Luzzati_coordinate_error_free",
    "refine_analyze.Luzzati_coordinate_error_obs",
    "refine_analyze.Luzzati_d_res_low_free",
    "refine_analyze.Luzzati_d_res_low_obs",
    "refine_analyze.Luzzati_sigma_a_free",
    "refine_analyze.Luzzati_sigma_a_obs",
    "refine_analyze.number_disordered_residues",
    "refine_analyze.occupancy_sum_hydrogen",
    "refine_analyze.occupancy_sum_non_hydrogen",
    "refine_analyze.pdbx_Luzzati_d_res_high_obs",
    "refine_analyze.pdbx_refine_id",
    "refine_hist.cycle_id",
    "refine_hist.d_res_high",
    "refine_hist.d_res_low",
    "refine_hist.number_atoms_solvent",
    "refine_hist.number_atoms_total",
    "refine_hist.pdbx_B_iso_mean_ligand",
    "refine_hist.pdbx_B_iso_mean_solvent",
    "refine_hist.pdbx_number_atoms_ligand",
    "refine_hist.pdbx_number_atoms_nucleic_acid",
    "refine_hist.pdbx_number_atoms_protein",
    "refine_hist.pdbx_number_residues_total",
    "refine_hist.pdbx_refine_id",
    "refine_ls_restr.dev_ideal",
    "refine_ls_restr.dev_ideal_target",
    "refine_ls_restr.number",
    "refine_ls_restr.pdbx_refine_id",
    "refine_ls_restr.pdbx_restraint_function",
    "refine_ls_restr.type",
    "refine_ls_restr.weight",
    "reflns.B_iso_Wilson_estimate",
    "reflns.R_free_details",
    "reflns.Rmerge_F_all",
    "reflns.Rmerge_F_obs",
    "reflns.d_resolution_high",
    "reflns.d_resolution_low",
    "reflns.data_reduction_details",
    "reflns.data_reduction_method",
    "reflns.details",
    "reflns.limit_h_max",
    "reflns.limit_h_min",
    "reflns.limit_k_max",
    "reflns.limit_k_min",
    "reflns.limit_l_max",
    "reflns.limit_l_min",
    "reflns.number_all",
    "reflns.number_obs",
    "reflns.observed_criterion",
    "reflns.observed_criterion_F_max",
    "reflns.observed_criterion_F_min",
    "reflns.observed_criterion_I_max",
    "reflns.observed_criterion_I_min",
    "reflns.observed_criterion_sigma_F",
    "reflns.observed_criterion_sigma_I",
    "reflns.pdbx_CC_half",
    "reflns.pdbx_R_split",
    "reflns.pdbx_Rmerge_I_obs",
    "reflns.pdbx_Rpim_I_all",
    "reflns.pdbx_Rrim_I_all",
    "reflns.pdbx_Rsym_value",
    "reflns.pdbx_chi_squared",
    "reflns.pdbx_diffrn_id",
    "reflns.pdbx_netI_over_av_sigmaI",
    "reflns.pdbx_netI_over_sigmaI",
    "reflns.pdbx_number_measured_all",
    "reflns.pdbx_ordinal",
    "reflns.pdbx_redundancy",
    "reflns.pdbx_scaling_rejects",
    "reflns.percent_possible_obs",
    "reflns.phase_calculation_details",
    "reflns_shell.Rmerge_F_all",
    "reflns_shell.Rmerge_F_obs",
    "reflns_shell.Rmerge_I_all",
    "reflns_shell.Rmerge_I_obs",
    "reflns_shell.d_res_high",
    "reflns_shell.d_res_low",
    "reflns_shell.meanI_over_sigI_all",
    "reflns_shell.meanI_over_sigI_obs",
    "reflns_shell.meanI_over_uI_all",
    "reflns_shell.number_measured_all",
    "reflns_shell.number_measured_obs",
    "reflns_shell.number_possible",
    "reflns_shell.number_unique_all",
    "reflns_shell.number_unique_obs",
    "reflns_shell.pdbx_CC_half",
    "reflns_shell.pdbx_R_split",
    "reflns_shell.pdbx_Rpim_I_all",
    "reflns_shell.pdbx_Rrim_I_all",
    "reflns_shell.pdbx_Rsym_value",
    "reflns_shell.pdbx_chi_squared",
    "reflns_shell.pdbx_diffrn_id",
    "reflns_shell.pdbx_netI_over_sigmaI_all",
    "reflns_shell.pdbx_netI_over_sigmaI_obs",
    "reflns_shell.pdbx_ordinal",
    "reflns_shell.pdbx_redundancy",
    "reflns_shell.pdbx_rejects",
    "reflns_shell.percent_possible_all",
    "reflns_shell.percent_possible_obs",
    "software.classification",
    "software.contact_author",
    "software.contact_author_email",
    "software.date",
    "software.description",
    "software.language",
    "software.location",
    "software.name",
    "software.os",
    "software.pdbx_ordinal",
    "software.type",
    "software.version",
    "struct.pdbx_CASP_flag",
    "struct.pdbx_descriptor",
    "struct.pdbx_model_details",
    "struct.pdbx_model_type_details",
    "struct.title",
    "struct_keywords.pdbx_keywords",
    "struct_keywords.text",
    "symmetry.Int_Tables_number",
    "symmetry.cell_setting",
    "symmetry.pdbx_full_space_group_name_H_M",
    "symmetry.space_group_name_H_M",
    "symmetry.space_group_name_Hall",
    "rcsb_external_references.id",
    "rcsb_external_references.type",
    "rcsb_external_references.link",
    "rcsb_binding_affinity.comp_id",
    "rcsb_binding_affinity.type",
    "rcsb_binding_affinity.value",
    "rcsb_binding_affinity.unit",
    "rcsb_binding_affinity.symbol",
    "rcsb_binding_affinity.reference_sequence_identity",
    "rcsb_binding_affinity.provenance_code",
    "rcsb_binding_affinity.link",
    "rcsb_polymer_entity_instance_container_identifiers.asym_id",
    "rcsb_polymer_entity_instance_container_identifiers.auth_asym_id",
    "rcsb_polymer_entity_instance_container_identifiers.auth_to_entity_poly_seq_mapping",
    "rcsb_polymer_entity_instance_container_identifiers.entity_id",
    "rcsb_polymer_entity_instance_container_identifiers.entry_id",
    "rcsb_polymer_entity_instance_container_identifiers.rcsb_id",
    "rcsb_polymer_instance_annotation.annotation_id",
    "rcsb_polymer_instance_annotation.assignment_version",
    "rcsb_polymer_instance_annotation.description",
    "rcsb_polymer_instance_annotation.name",
    "rcsb_polymer_instance_annotation.ordinal",
    "rcsb_polymer_instance_annotation.provenance_source",
    "rcsb_polymer_instance_annotation.type",
    "rcsb_polymer_instance_annotation.annotation_lineage.depth",
    "rcsb_polymer_instance_annotation.annotation_lineage.id",
    "rcsb_polymer_instance_annotation.annotation_lineage.name",
    "rcsb_polymer_instance_feature.assignment_version",
    "rcsb_polymer_instance_feature.description",
    "rcsb_polymer_instance_feature.feature_id",
    "rcsb_polymer_instance_feature.name",
    "rcsb_polymer_instance_feature.ordinal",
    "rcsb_polymer_instance_feature.provenance_source",
    "rcsb_polymer_instance_feature.reference_scheme",
    "rcsb_polymer_instance_feature.type",
    "rcsb_polymer_instance_feature.feature_positions.beg_comp_id",
    "rcsb_polymer_instance_feature.feature_positions.beg_seq_id",
    "rcsb_polymer_instance_feature.feature_positions.end_seq_id",
    "rcsb_polymer_instance_feature.feature_positions.value",
    "rcsb_polymer_instance_feature.additional_properties.name",
    "rcsb_polymer_instance_feature.additional_properties.values",
    "rcsb_polymer_instance_feature_summary.count",
    "rcsb_polymer_instance_feature_summary.coverage",
    "rcsb_polymer_instance_feature_summary.maximum_length",
    "rcsb_polymer_instance_feature_summary.maximum_value",
    "rcsb_polymer_instance_feature_summary.minimum_length",
    "rcsb_polymer_instance_feature_summary.minimum_value",
    "rcsb_polymer_instance_feature_summary.type",
    "rcsb_polymer_struct_conn.connect_type",
    "rcsb_polymer_struct_conn.description",
    "rcsb_polymer_struct_conn.dist_value",
    "rcsb_polymer_struct_conn.id",
    "rcsb_polymer_struct_conn.ordinal_id",
    "rcsb_polymer_struct_conn.role",
    "rcsb_polymer_struct_conn.value_order",
    "rcsb_polymer_struct_conn.connect_target.auth_asym_id",
    "rcsb_polymer_struct_conn.connect_target.auth_seq_id",
    "rcsb_polymer_struct_conn.connect_target.label_alt_id",
    "rcsb_polymer_struct_conn.connect_target.label_asym_id",
    "rcsb_polymer_struct_conn.connect_target.label_atom_id",
    "rcsb_polymer_struct_conn.connect_target.label_comp_id",
    "rcsb_polymer_struct_conn.connect_target.label_seq_id",
    "rcsb_polymer_struct_conn.connect_target.symmetry",
    "rcsb_polymer_struct_conn.connect_partner.label_alt_id",
    "rcsb_polymer_struct_conn.connect_partner.label_asym_id",
    "rcsb_polymer_struct_conn.connect_partner.label_atom_id",
    "rcsb_polymer_struct_conn.connect_partner.label_comp_id",
    "rcsb_polymer_struct_conn.connect_partner.label_seq_id",
    "rcsb_polymer_struct_conn.connect_partner.symmetry",
    "pdbx_entity_nonpoly.comp_id",
    "pdbx_entity_nonpoly.entity_id",
    "pdbx_entity_nonpoly.name",
    "pdbx_entity_nonpoly.rcsb_prd_id",
    "rcsb_nonpolymer_entity.details",
    "rcsb_nonpolymer_entity.formula_weight",
    "rcsb_nonpolymer_entity.pdbx_description",
    "rcsb_nonpolymer_entity.pdbx_number_of_molecules",
    "rcsb_nonpolymer_entity_annotation.annotation_id",
    "rcsb_nonpolymer_entity_annotation.assignment_version",
    "rcsb_nonpolymer_entity_annotation.comp_id",
    "rcsb_nonpolymer_entity_annotation.description",
    "rcsb_nonpolymer_entity_annotation.name",
    "rcsb_nonpolymer_entity_annotation.provenance_source",
    "rcsb_nonpolymer_entity_annotation.type",
    "rcsb_nonpolymer_entity_annotation.annotation_lineage.depth",
    "rcsb_nonpolymer_entity_annotation.annotation_lineage.id",
    "rcsb_nonpolymer_entity_annotation.annotation_lineage.name",
    "rcsb_nonpolymer_entity_container_identifiers.asym_ids",
    "rcsb_nonpolymer_entity_container_identifiers.auth_asym_ids",
    "rcsb_nonpolymer_entity_container_identifiers.entity_id",
    "rcsb_nonpolymer_entity_container_identifiers.entry_id",
    "rcsb_nonpolymer_entity_container_identifiers.nonpolymer_comp_id",
    "rcsb_nonpolymer_entity_container_identifiers.prd_id",
    "rcsb_nonpolymer_entity_container_identifiers.rcsb_id",
    "rcsb_nonpolymer_entity_container_identifiers.reference_chemical_identifiers_provenance_source",
    "rcsb_nonpolymer_entity_container_identifiers.reference_chemical_identifiers_resource_accession",
    "rcsb_nonpolymer_entity_container_identifiers.reference_chemical_identifiers_resource_name",
    "rcsb_nonpolymer_entity_feature.assignment_version",
    "rcsb_nonpolymer_entity_feature.comp_id",
    "rcsb_nonpolymer_entity_feature.description",
    "rcsb_nonpolymer_entity_feature.feature_id",
    "rcsb_nonpolymer_entity_feature.name",
    "rcsb_nonpolymer_entity_feature.provenance_source",
    "rcsb_nonpolymer_entity_feature.type",
    "rcsb_nonpolymer_entity_feature.value",
    "rcsb_nonpolymer_entity_feature.additional_properties.name",
    "rcsb_nonpolymer_entity_feature.additional_properties.values",
    "rcsb_nonpolymer_entity_feature_summary.comp_id",
    "rcsb_nonpolymer_entity_feature_summary.count",
    "rcsb_nonpolymer_entity_feature_summary.maximum_length",
    "rcsb_nonpolymer_entity_feature_summary.maximum_value",
    "rcsb_nonpolymer_entity_feature_summary.minimum_length",
    "rcsb_nonpolymer_entity_feature_summary.minimum_value",
    "rcsb_nonpolymer_entity_feature_summary.type",
    "rcsb_nonpolymer_entity_keywords.text",
    "rcsb_nonpolymer_entity_name_com.name",
    "rcsb_pubmed_container_identifiers.pubmed_id",
    "rcsb_pubmed_central_id",
    "rcsb_pubmed_doi",
    "rcsb_pubmed_abstract_text",
    "rcsb_pubmed_affiliation_info",
    "rcsb_pubmed_mesh_descriptors",
    "rcsb_pubmed_mesh_descriptors_lineage.id",
    "rcsb_pubmed_mesh_descriptors_lineage.name",
    "rcsb_pubmed_mesh_descriptors_lineage.depth",
    "rcsb_cluster_membership.cluster_id",
    "rcsb_cluster_membership.identity",
    "entity_poly.nstd_linkage",
    "entity_poly.nstd_monomer",
    "entity_poly.pdbx_seq_one_letter_code",
    "entity_poly.pdbx_seq_one_letter_code_can",
    "entity_poly.pdbx_strand_id",
    "entity_poly.pdbx_target_identifier",
    "entity_poly.rcsb_artifact_monomer_count",
    "entity_poly.rcsb_conflict_count",
    "entity_poly.rcsb_deletion_count",
    "entity_poly.rcsb_entity_polymer_type",
    "entity_poly.rcsb_insertion_count",
    "entity_poly.rcsb_mutation_count",
    "entity_poly.rcsb_non_std_monomer_count",
    "entity_poly.rcsb_non_std_monomers",
    "entity_poly.rcsb_prd_id",
    "entity_poly.rcsb_sample_sequence_length",
    "entity_poly.type",
    "entity_src_gen.expression_system_id",
    "entity_src_gen.gene_src_common_name",
    "entity_src_gen.gene_src_details",
    "entity_src_gen.gene_src_genus",
    "entity_src_gen.gene_src_species",
    "entity_src_gen.gene_src_strain",
    "entity_src_gen.gene_src_tissue",
    "entity_src_gen.gene_src_tissue_fraction",
    "entity_src_gen.host_org_common_name",
    "entity_src_gen.host_org_details",
    "entity_src_gen.host_org_genus",
    "entity_src_gen.host_org_species",
    "entity_src_gen.pdbx_alt_source_flag",
    "entity_src_gen.pdbx_beg_seq_num",
    "entity_src_gen.pdbx_description",
    "entity_src_gen.pdbx_end_seq_num",
    "entity_src_gen.pdbx_gene_src_atcc",
    "entity_src_gen.pdbx_gene_src_cell",
    "entity_src_gen.pdbx_gene_src_cell_line",
    "entity_src_gen.pdbx_gene_src_cellular_location",
    "entity_src_gen.pdbx_gene_src_fragment",
    "entity_src_gen.pdbx_gene_src_gene",
    "entity_src_gen.pdbx_gene_src_ncbi_taxonomy_id",
    "entity_src_gen.pdbx_gene_src_organ",
    "entity_src_gen.pdbx_gene_src_organelle",
    "entity_src_gen.pdbx_gene_src_scientific_name",
    "entity_src_gen.pdbx_gene_src_variant",
    "entity_src_gen.pdbx_host_org_atcc",
    "entity_src_gen.pdbx_host_org_cell",
    "entity_src_gen.pdbx_host_org_cell_line",
    "entity_src_gen.pdbx_host_org_cellular_location",
    "entity_src_gen.pdbx_host_org_culture_collection",
    "entity_src_gen.pdbx_host_org_gene",
    "entity_src_gen.pdbx_host_org_ncbi_taxonomy_id",
    "entity_src_gen.pdbx_host_org_organ",
    "entity_src_gen.pdbx_host_org_organelle",
    "entity_src_gen.pdbx_host_org_scientific_name",
    "entity_src_gen.pdbx_host_org_strain",
    "entity_src_gen.pdbx_host_org_tissue",
    "entity_src_gen.pdbx_host_org_tissue_fraction",
    "entity_src_gen.pdbx_host_org_variant",
    "entity_src_gen.pdbx_host_org_vector",
    "entity_src_gen.pdbx_host_org_vector_type",
    "entity_src_gen.pdbx_seq_type",
    "entity_src_gen.pdbx_src_id",
    "entity_src_gen.plasmid_details",
    "entity_src_gen.plasmid_name",
    "entity_src_nat.common_name",
    "entity_src_nat.details",
    "entity_src_nat.genus",
    "entity_src_nat.pdbx_alt_source_flag",
    "entity_src_nat.pdbx_atcc",
    "entity_src_nat.pdbx_beg_seq_num",
    "entity_src_nat.pdbx_cell",
    "entity_src_nat.pdbx_cell_line",
    "entity_src_nat.pdbx_cellular_location",
    "entity_src_nat.pdbx_end_seq_num",
    "entity_src_nat.pdbx_fragment",
    "entity_src_nat.pdbx_ncbi_taxonomy_id",
    "entity_src_nat.pdbx_organ",
    "entity_src_nat.pdbx_organelle",
    "entity_src_nat.pdbx_organism_scientific",
    "entity_src_nat.pdbx_plasmid_details",
    "entity_src_nat.pdbx_plasmid_name",
    "entity_src_nat.pdbx_secretion",
    "entity_src_nat.pdbx_src_id",
    "entity_src_nat.pdbx_variant",
    "entity_src_nat.species",
    "entity_src_nat.strain",
    "entity_src_nat.tissue",
    "entity_src_nat.tissue_fraction",
    "pdbx_entity_src_syn.details",
    "pdbx_entity_src_syn.ncbi_taxonomy_id",
    "pdbx_entity_src_syn.organism_common_name",
    "pdbx_entity_src_syn.organism_scientific",
    "pdbx_entity_src_syn.pdbx_alt_source_flag",
    "pdbx_entity_src_syn.pdbx_beg_seq_num",
    "pdbx_entity_src_syn.pdbx_end_seq_num",
    "pdbx_entity_src_syn.pdbx_src_id",
    "rcsb_entity_host_organism.beg_seq_num",
    "rcsb_entity_host_organism.common_name",
    "rcsb_entity_host_organism.end_seq_num",
    "rcsb_entity_host_organism.ncbi_common_names",
    "rcsb_entity_host_organism.ncbi_parent_scientific_name",
    "rcsb_entity_host_organism.ncbi_scientific_name",
    "rcsb_entity_host_organism.ncbi_taxonomy_id",
    "rcsb_entity_host_organism.pdbx_src_id",
    "rcsb_entity_host_organism.provenance_source",
    "rcsb_entity_host_organism.scientific_name",
    "rcsb_entity_host_organism.taxonomy_lineage.depth",
    "rcsb_entity_host_organism.taxonomy_lineage.id",
    "rcsb_entity_host_organism.taxonomy_lineage.name",
    "rcsb_entity_source_organism.beg_seq_num",
    "rcsb_entity_source_organism.common_name",
    "rcsb_entity_source_organism.end_seq_num",
    "rcsb_entity_source_organism.ncbi_common_names",
    "rcsb_entity_source_organism.ncbi_parent_scientific_name",
    "rcsb_entity_source_organism.ncbi_scientific_name",
    "rcsb_entity_source_organism.ncbi_taxonomy_id",
    "rcsb_entity_source_organism.pdbx_src_id",
    "rcsb_entity_source_organism.provenance_source",
    "rcsb_entity_source_organism.scientific_name",
    "rcsb_entity_source_organism.source_type",
    "rcsb_entity_source_organism.taxonomy_lineage.depth",
    "rcsb_entity_source_organism.taxonomy_lineage.id",
    "rcsb_entity_source_organism.taxonomy_lineage.name",
    "rcsb_entity_source_organism.rcsb_gene_name.provenance_source",
    "rcsb_entity_source_organism.rcsb_gene_name.value",
    "rcsb_polymer_entity.details",
    "rcsb_polymer_entity.formula_weight",
    "rcsb_polymer_entity.pdbx_description",
    "rcsb_polymer_entity.pdbx_ec",
    "rcsb_polymer_entity.pdbx_fragment",
    "rcsb_polymer_entity.pdbx_mutation",
    "rcsb_polymer_entity.pdbx_number_of_molecules",
    "rcsb_polymer_entity.rcsb_multiple_source_flag",
    "rcsb_polymer_entity.rcsb_source_part_count",
    "rcsb_polymer_entity.rcsb_source_taxonomy_count",
    "rcsb_polymer_entity.src_method",
    "rcsb_polymer_entity.rcsb_ec_lineage.depth",
    "rcsb_polymer_entity.rcsb_ec_lineage.id",
    "rcsb_polymer_entity.rcsb_ec_lineage.name",
    "rcsb_polymer_entity.rcsb_macromolecular_names_combined.name",
    "rcsb_polymer_entity.rcsb_macromolecular_names_combined.provenance_code",
    "rcsb_polymer_entity.rcsb_macromolecular_names_combined.provenance_source",
    "rcsb_polymer_entity.rcsb_enzyme_class_combined.depth",
    "rcsb_polymer_entity.rcsb_enzyme_class_combined.ec",
    "rcsb_polymer_entity.rcsb_enzyme_class_combined.provenance_source",
    "rcsb_polymer_entity_align.provenance_source",
    "rcsb_polymer_entity_align.reference_database_accession",
    "rcsb_polymer_entity_align.reference_database_isoform",
    "rcsb_polymer_entity_align.reference_database_name",
    "rcsb_polymer_entity_align.aligned_regions.entity_beg_seq_id",
    "rcsb_polymer_entity_align.aligned_regions.length",
    "rcsb_polymer_entity_align.aligned_regions.ref_beg_seq_id",
    "rcsb_polymer_entity_annotation.annotation_id",
    "rcsb_polymer_entity_annotation.assignment_version",
    "rcsb_polymer_entity_annotation.description",
    "rcsb_polymer_entity_annotation.name",
    "rcsb_polymer_entity_annotation.provenance_source",
    "rcsb_polymer_entity_annotation.type",
    "rcsb_polymer_entity_annotation.annotation_lineage.depth",
    "rcsb_polymer_entity_annotation.annotation_lineage.id",
    "rcsb_polymer_entity_annotation.annotation_lineage.name",
    "rcsb_polymer_entity_container_identifiers.asym_ids",
    "rcsb_polymer_entity_container_identifiers.auth_asym_ids",
    "rcsb_polymer_entity_container_identifiers.chem_comp_monomers",
    "rcsb_polymer_entity_container_identifiers.chem_comp_nstd_monomers",
    "rcsb_polymer_entity_container_identifiers.entity_id",
    "rcsb_polymer_entity_container_identifiers.entry_id",
    "rcsb_polymer_entity_container_identifiers.prd_id",
    "rcsb_polymer_entity_container_identifiers.rcsb_id",
    "rcsb_polymer_entity_container_identifiers.reference_sequence_identifiers.database_accession",
    "rcsb_polymer_entity_container_identifiers.reference_sequence_identifiers.database_isoform",
    "rcsb_polymer_entity_container_identifiers.reference_sequence_identifiers.database_name",
    "rcsb_polymer_entity_container_identifiers.reference_sequence_identifiers.provenance_source",
    "rcsb_polymer_entity_container_identifiers.uniprot_ids",
    "rcsb_polymer_entity_feature.assignment_version",
    "rcsb_polymer_entity_feature.description",
    "rcsb_polymer_entity_feature.feature_id",
    "rcsb_polymer_entity_feature.name",
    "rcsb_polymer_entity_feature.provenance_source",
    "rcsb_polymer_entity_feature.reference_scheme",
    "rcsb_polymer_entity_feature.type",
    "rcsb_polymer_entity_feature.feature_positions.beg_comp_id",
    "rcsb_polymer_entity_feature.feature_positions.beg_seq_id",
    "rcsb_polymer_entity_feature.feature_positions.end_seq_id",
    "rcsb_polymer_entity_feature.feature_positions.value",
    "rcsb_polymer_entity_feature.additional_properties.name",
    "rcsb_polymer_entity_feature.additional_properties.values",
    "rcsb_polymer_entity_feature_summary.count",
    "rcsb_polymer_entity_feature_summary.coverage",
    "rcsb_polymer_entity_feature_summary.maximum_length",
    "rcsb_polymer_entity_feature_summary.maximum_value",
    "rcsb_polymer_entity_feature_summary.minimum_length",
    "rcsb_polymer_entity_feature_summary.minimum_value",
    "rcsb_polymer_entity_feature_summary.type",
    "rcsb_polymer_entity_keywords.text",
    "rcsb_polymer_entity_name_com.name",
    "rcsb_polymer_entity_name_sys.name",
    "rcsb_polymer_entity_name_sys.system",
    "rcsb_genomic_lineage.id",
    "rcsb_genomic_lineage.name",
    "rcsb_genomic_lineage.depth",
    "rcsb_membrane_lineage.id",
    "rcsb_membrane_lineage.name",
    "rcsb_membrane_lineage.depth",
    "rcsb_membrane_lineage_provenance_code",
    "rcsb_cluster_flexibility.link",
    "rcsb_cluster_flexibility.label",
    "rcsb_cluster_flexibility.avg_rmsd",
    "rcsb_cluster_flexibility.max_rmsd",
    "rcsb_cluster_flexibility.provenance_code",
    "chem_comp.formula",
    "chem_comp.formula_weight",
    "chem_comp.id",
    "chem_comp.mon_nstd_parent_comp_id",
    "chem_comp.name",
    "chem_comp.one_letter_code",
    "chem_comp.pdbx_ambiguous_flag",
    "chem_comp.pdbx_formal_charge",
    "chem_comp.pdbx_initial_date",
    "chem_comp.pdbx_modified_date",
    "chem_comp.pdbx_processing_site",
    "chem_comp.pdbx_release_status",
    "chem_comp.pdbx_replaced_by",
    "chem_comp.pdbx_replaces",
    "chem_comp.pdbx_subcomponent_list",
    "chem_comp.three_letter_code",
    "chem_comp.type",
    "pdbx_chem_comp_audit.action_type",
    "pdbx_chem_comp_audit.comp_id",
    "pdbx_chem_comp_audit.date",
    "pdbx_chem_comp_audit.details",
    "pdbx_chem_comp_audit.ordinal",
    "pdbx_chem_comp_descriptor.comp_id",
    "pdbx_chem_comp_descriptor.descriptor",
    "pdbx_chem_comp_descriptor.program",
    "pdbx_chem_comp_descriptor.program_version",
    "pdbx_chem_comp_descriptor.type",
    "pdbx_chem_comp_feature.comp_id",
    "pdbx_chem_comp_feature.source",
    "pdbx_chem_comp_feature.type",
    "pdbx_chem_comp_feature.value",
    "pdbx_chem_comp_identifier.comp_id",
    "pdbx_chem_comp_identifier.identifier",
    "pdbx_chem_comp_identifier.program",
    "pdbx_chem_comp_identifier.program_version",
    "pdbx_chem_comp_identifier.type",
    "pdbx_family_prd_audit.action_type",
    "pdbx_family_prd_audit.annotator",
    "pdbx_family_prd_audit.date",
    "pdbx_family_prd_audit.details",
    "pdbx_family_prd_audit.family_prd_id",
    "pdbx_family_prd_audit.processing_site",
    "pdbx_prd_audit.action_type",
    "pdbx_prd_audit.annotator",
    "pdbx_prd_audit.date",
    "pdbx_prd_audit.details",
    "pdbx_prd_audit.prd_id",
    "pdbx_prd_audit.processing_site",
    "pdbx_reference_entity_list.component_id",
    "pdbx_reference_entity_list.details",
    "pdbx_reference_entity_list.prd_id",
    "pdbx_reference_entity_list.ref_entity_id",
    "pdbx_reference_entity_list.type",
    "pdbx_reference_entity_poly.db_code",
    "pdbx_reference_entity_poly.db_name",
    "pdbx_reference_entity_poly.prd_id",
    "pdbx_reference_entity_poly.ref_entity_id",
    "pdbx_reference_entity_poly.type",
    "pdbx_reference_entity_poly_link.atom_id_1",
    "pdbx_reference_entity_poly_link.atom_id_2",
    "pdbx_reference_entity_poly_link.comp_id_1",
    "pdbx_reference_entity_poly_link.comp_id_2",
    "pdbx_reference_entity_poly_link.component_id",
    "pdbx_reference_entity_poly_link.entity_seq_num_1",
    "pdbx_reference_entity_poly_link.entity_seq_num_2",
    "pdbx_reference_entity_poly_link.link_id",
    "pdbx_reference_entity_poly_link.prd_id",
    "pdbx_reference_entity_poly_link.ref_entity_id",
    "pdbx_reference_entity_poly_link.value_order",
    "pdbx_reference_entity_poly_seq.hetero",
    "pdbx_reference_entity_poly_seq.mon_id",
    "pdbx_reference_entity_poly_seq.num",
    "pdbx_reference_entity_poly_seq.observed",
    "pdbx_reference_entity_poly_seq.parent_mon_id",
    "pdbx_reference_entity_poly_seq.prd_id",
    "pdbx_reference_entity_poly_seq.ref_entity_id",
    "pdbx_reference_entity_sequence.NRP_flag",
    "pdbx_reference_entity_sequence.one_letter_codes",
    "pdbx_reference_entity_sequence.prd_id",
    "pdbx_reference_entity_sequence.ref_entity_id",
    "pdbx_reference_entity_sequence.type",
    "pdbx_reference_entity_src_nat.atcc",
    "pdbx_reference_entity_src_nat.db_code",
    "pdbx_reference_entity_src_nat.db_name",
    "pdbx_reference_entity_src_nat.ordinal",
    "pdbx_reference_entity_src_nat.organism_scientific",
    "pdbx_reference_entity_src_nat.prd_id",
    "pdbx_reference_entity_src_nat.ref_entity_id",
    "pdbx_reference_entity_src_nat.source",
    "pdbx_reference_entity_src_nat.source_id",
    "pdbx_reference_entity_src_nat.taxid",
    "pdbx_reference_molecule.chem_comp_id",
    "pdbx_reference_molecule.class",
    "pdbx_reference_molecule.class_evidence_code",
    "pdbx_reference_molecule.compound_details",
    "pdbx_reference_molecule.description",
    "pdbx_reference_molecule.formula",
    "pdbx_reference_molecule.formula_weight",
    "pdbx_reference_molecule.name",
    "pdbx_reference_molecule.prd_id",
    "pdbx_reference_molecule.release_status",
    "pdbx_reference_molecule.replaced_by",
    "pdbx_reference_molecule.replaces",
    "pdbx_reference_molecule.represent_as",
    "pdbx_reference_molecule.representative_PDB_id_code",
    "pdbx_reference_molecule.type",
    "pdbx_reference_molecule.type_evidence_code",
    "pdbx_reference_molecule_annotation.family_prd_id",
    "pdbx_reference_molecule_annotation.ordinal",
    "pdbx_reference_molecule_annotation.prd_id",
    "pdbx_reference_molecule_annotation.source",
    "pdbx_reference_molecule_annotation.text",
    "pdbx_reference_molecule_annotation.type",
    "pdbx_reference_molecule_details.family_prd_id",
    "pdbx_reference_molecule_details.ordinal",
    "pdbx_reference_molecule_details.source",
    "pdbx_reference_molecule_details.source_id",
    "pdbx_reference_molecule_details.text",
    "pdbx_reference_molecule_family.family_prd_id",
    "pdbx_reference_molecule_family.name",
    "pdbx_reference_molecule_family.release_status",
    "pdbx_reference_molecule_family.replaced_by",
    "pdbx_reference_molecule_family.replaces",
    "pdbx_reference_molecule_features.family_prd_id",
    "pdbx_reference_molecule_features.ordinal",
    "pdbx_reference_molecule_features.prd_id",
    "pdbx_reference_molecule_features.source",
    "pdbx_reference_molecule_features.source_ordinal",
    "pdbx_reference_molecule_features.type",
    "pdbx_reference_molecule_features.value",
    "pdbx_reference_molecule_list.family_prd_id",
    "pdbx_reference_molecule_list.prd_id",
    "pdbx_reference_molecule_related_structures.citation_id",
    "pdbx_reference_molecule_related_structures.db_accession",
    "pdbx_reference_molecule_related_structures.db_code",
    "pdbx_reference_molecule_related_structures.db_name",
    "pdbx_reference_molecule_related_structures.family_prd_id",
    "pdbx_reference_molecule_related_structures.formula",
    "pdbx_reference_molecule_related_structures.name",
    "pdbx_reference_molecule_related_structures.ordinal",
    "pdbx_reference_molecule_synonyms.family_prd_id",
    "pdbx_reference_molecule_synonyms.name",
    "pdbx_reference_molecule_synonyms.ordinal",
    "pdbx_reference_molecule_synonyms.prd_id",
    "pdbx_reference_molecule_synonyms.source",
    "rcsb_bird_citation.id",
    "rcsb_bird_citation.journal_abbrev",
    "rcsb_bird_citation.journal_volume",
    "rcsb_bird_citation.page_first",
    "rcsb_bird_citation.page_last",
    "rcsb_bird_citation.pdbx_database_id_DOI",
    "rcsb_bird_citation.pdbx_database_id_PubMed",
    "rcsb_bird_citation.rcsb_authors",
    "rcsb_bird_citation.title",
    "rcsb_bird_citation.year",
    "rcsb_chem_comp_annotation.annotation_id",
    "rcsb_chem_comp_annotation.assignment_version",
    "rcsb_chem_comp_annotation.description",
    "rcsb_chem_comp_annotation.name",
    "rcsb_chem_comp_annotation.provenance_source",
    "rcsb_chem_comp_annotation.type",
    "rcsb_chem_comp_annotation.annotation_lineage.depth",
    "rcsb_chem_comp_annotation.annotation_lineage.id",
    "rcsb_chem_comp_annotation.annotation_lineage.name",
    "rcsb_chem_comp_container_identifiers.atc_codes",
    "rcsb_chem_comp_container_identifiers.comp_id",
    "rcsb_chem_comp_container_identifiers.drugbank_id",
    "rcsb_chem_comp_container_identifiers.prd_id",
    "rcsb_chem_comp_container_identifiers.rcsb_id",
    "rcsb_chem_comp_container_identifiers.subcomponent_ids",
    "rcsb_chem_comp_descriptor.InChI",
    "rcsb_chem_comp_descriptor.InChIKey",
    "rcsb_chem_comp_descriptor.SMILES",
    "rcsb_chem_comp_descriptor.SMILES_stereo",
    "rcsb_chem_comp_descriptor.comp_id",
    "rcsb_chem_comp_info.atom_count",
    "rcsb_chem_comp_info.atom_count_chiral",
    "rcsb_chem_comp_info.atom_count_heavy",
    "rcsb_chem_comp_info.bond_count",
    "rcsb_chem_comp_info.bond_count_aromatic",
    "rcsb_chem_comp_info.comp_id",
    "rcsb_chem_comp_info.initial_release_date",
    "rcsb_chem_comp_info.release_status",
    "rcsb_chem_comp_info.revision_date",
    "rcsb_chem_comp_related.comp_id",
    "rcsb_chem_comp_related.ordinal",
    "rcsb_chem_comp_related.related_mapping_method",
    "rcsb_chem_comp_related.resource_accession_code",
    "rcsb_chem_comp_related.resource_name",
    "rcsb_chem_comp_synonyms.comp_id",
    "rcsb_chem_comp_synonyms.name",
    "rcsb_chem_comp_synonyms.ordinal",
    "rcsb_chem_comp_synonyms.provenance_source",
    "rcsb_chem_comp_synonyms.type",
    "rcsb_chem_comp_target.comp_id",
    "rcsb_chem_comp_target.interaction_type",
    "rcsb_chem_comp_target.name",
    "rcsb_chem_comp_target.ordinal",
    "rcsb_chem_comp_target.provenance_source",
    "rcsb_chem_comp_target.reference_database_accession_code",
    "rcsb_chem_comp_target.reference_database_name",
    "rcsb_chem_comp_target.target_actions",
    "rcsb_schema_container_identifiers.collection_name",
    "rcsb_schema_container_identifiers.collection_schema_version",
    "rcsb_schema_container_identifiers.schema_name",
    "pdbx_struct_assembly.details",
    "pdbx_struct_assembly.id",
    "pdbx_struct_assembly.method_details",
    "pdbx_struct_assembly.oligomeric_count",
    "pdbx_struct_assembly.oligomeric_details",
    "pdbx_struct_assembly.rcsb_candidate_assembly",
    "pdbx_struct_assembly.rcsb_details",
    "pdbx_struct_assembly_auth_evidence.assembly_id",
    "pdbx_struct_assembly_auth_evidence.details",
    "pdbx_struct_assembly_auth_evidence.experimental_support",
    "pdbx_struct_assembly_auth_evidence.id",
    "pdbx_struct_assembly_gen.assembly_id",
    "pdbx_struct_assembly_gen.asym_id_list",
    "pdbx_struct_assembly_gen.oper_expression",
    "pdbx_struct_assembly_gen.ordinal",
    "pdbx_struct_assembly_prop.assembly_id",
    "pdbx_struct_assembly_prop.biol_id",
    "pdbx_struct_assembly_prop.type",
    "pdbx_struct_assembly_prop.value",
    "pdbx_struct_oper_list.id",
    "pdbx_struct_oper_list.matrix_1_1",
    "pdbx_struct_oper_list.matrix_1_2",
    "pdbx_struct_oper_list.matrix_1_3",
    "pdbx_struct_oper_list.matrix_2_1",
    "pdbx_struct_oper_list.matrix_2_2",
    "pdbx_struct_oper_list.matrix_2_3",
    "pdbx_struct_oper_list.matrix_3_1",
    "pdbx_struct_oper_list.matrix_3_2",
    "pdbx_struct_oper_list.matrix_3_3",
    "pdbx_struct_oper_list.name",
    "pdbx_struct_oper_list.symmetry_operation",
    "pdbx_struct_oper_list.type",
    "pdbx_struct_oper_list.vector_1",
    "pdbx_struct_oper_list.vector_2",
    "pdbx_struct_oper_list.vector_3",
    "rcsb_assembly_container_identifiers.assembly_id",
    "rcsb_assembly_container_identifiers.entry_id",
    "rcsb_assembly_container_identifiers.rcsb_id",
    "rcsb_assembly_info.assembly_id",
    "rcsb_assembly_info.atom_count",
    "rcsb_assembly_info.branched_atom_count",
    "rcsb_assembly_info.branched_entity_count",
    "rcsb_assembly_info.branched_entity_instance_count",
    "rcsb_assembly_info.entry_id",
    "rcsb_assembly_info.hydrogen_atom_count",
    "rcsb_assembly_info.modeled_polymer_monomer_count",
    "rcsb_assembly_info.na_polymer_entity_types",
    "rcsb_assembly_info.nonpolymer_atom_count",
    "rcsb_assembly_info.nonpolymer_entity_count",
    "rcsb_assembly_info.nonpolymer_entity_instance_count",
    "rcsb_assembly_info.polymer_atom_count",
    "rcsb_assembly_info.polymer_composition",
    "rcsb_assembly_info.polymer_entity_count",
    "rcsb_assembly_info.polymer_entity_count_DNA",
    "rcsb_assembly_info.polymer_entity_count_RNA",
    "rcsb_assembly_info.polymer_entity_count_nucleic_acid",
    "rcsb_assembly_info.polymer_entity_count_nucleic_acid_hybrid",
    "rcsb_assembly_info.polymer_entity_count_protein",
    "rcsb_assembly_info.polymer_entity_instance_count",
    "rcsb_assembly_info.polymer_entity_instance_count_DNA",
    "rcsb_assembly_info.polymer_entity_instance_count_RNA",
    "rcsb_assembly_info.polymer_entity_instance_count_nucleic_acid",
    "rcsb_assembly_info.polymer_entity_instance_count_nucleic_acid_hybrid",
    "rcsb_assembly_info.polymer_entity_instance_count_protein",
    "rcsb_assembly_info.polymer_monomer_count",
    "rcsb_assembly_info.selected_polymer_entity_types",
    "rcsb_assembly_info.solvent_atom_count",
    "rcsb_assembly_info.solvent_entity_count",
    "rcsb_assembly_info.solvent_entity_instance_count",
    "rcsb_assembly_info.unmodeled_polymer_monomer_count",
    "rcsb_struct_symmetry.symbol",
    "rcsb_struct_symmetry.type",
    "rcsb_struct_symmetry.stoichiometry",
    "rcsb_struct_symmetry.oligomeric_state",
    "rcsb_struct_symmetry.clusters.members.asym_id",
    "rcsb_struct_symmetry.clusters.members.pdbx_struct_oper_list_ids",
    "rcsb_struct_symmetry.clusters.avg_rmsd",
    "rcsb_struct_symmetry.rotation_axes.start",
    "rcsb_struct_symmetry.rotation_axes.end",
    "rcsb_struct_symmetry.rotation_axes.order",
    "rcsb_struct_symmetry.kind",
    "rcsb_struct_symmetry_provenance_code",
    "rcsb_struct_symmetry_lineage.id",
    "rcsb_struct_symmetry_lineage.name",
    "rcsb_struct_symmetry_lineage.depth",
    "rcsb_nonpolymer_entity_instance_container_identifiers.asym_id",
    "rcsb_nonpolymer_entity_instance_container_identifiers.auth_asym_id",
    "rcsb_nonpolymer_entity_instance_container_identifiers.auth_seq_id",
    "rcsb_nonpolymer_entity_instance_container_identifiers.comp_id",
    "rcsb_nonpolymer_entity_instance_container_identifiers.entity_id",
    "rcsb_nonpolymer_entity_instance_container_identifiers.entry_id",
    "rcsb_nonpolymer_entity_instance_container_identifiers.rcsb_id",
    "rcsb_nonpolymer_instance_annotation.annotation_id",
    "rcsb_nonpolymer_instance_annotation.assignment_version",
    "rcsb_nonpolymer_instance_annotation.comp_id",
    "rcsb_nonpolymer_instance_annotation.description",
    "rcsb_nonpolymer_instance_annotation.name",
    "rcsb_nonpolymer_instance_annotation.ordinal",
    "rcsb_nonpolymer_instance_annotation.provenance_source",
    "rcsb_nonpolymer_instance_annotation.type",
    "rcsb_nonpolymer_instance_annotation.annotation_lineage.depth",
    "rcsb_nonpolymer_instance_annotation.annotation_lineage.id",
    "rcsb_nonpolymer_instance_annotation.annotation_lineage.name",
    "rcsb_nonpolymer_instance_feature.assignment_version",
    "rcsb_nonpolymer_instance_feature.comp_id",
    "rcsb_nonpolymer_instance_feature.description",
    "rcsb_nonpolymer_instance_feature.feature_id",
    "rcsb_nonpolymer_instance_feature.name",
    "rcsb_nonpolymer_instance_feature.ordinal",
    "rcsb_nonpolymer_instance_feature.provenance_source",
    "rcsb_nonpolymer_instance_feature.type",
    "rcsb_nonpolymer_instance_feature.feature_value.comp_id",
    "rcsb_nonpolymer_instance_feature.feature_value.details",
    "rcsb_nonpolymer_instance_feature.feature_value.reference",
    "rcsb_nonpolymer_instance_feature.feature_value.reported",
    "rcsb_nonpolymer_instance_feature.feature_value.uncertainty_estimate",
    "rcsb_nonpolymer_instance_feature.feature_value.uncertainty_estimate_type",
    "rcsb_nonpolymer_instance_feature.additional_properties.name",
    "rcsb_nonpolymer_instance_feature.additional_properties.values",
    "rcsb_nonpolymer_instance_feature_summary.comp_id",
    "rcsb_nonpolymer_instance_feature_summary.count",
    "rcsb_nonpolymer_instance_feature_summary.maximum_length",
    "rcsb_nonpolymer_instance_feature_summary.maximum_value",
    "rcsb_nonpolymer_instance_feature_summary.minimum_length",
    "rcsb_nonpolymer_instance_feature_summary.minimum_value",
    "rcsb_nonpolymer_instance_feature_summary.type",
    "rcsb_nonpolymer_instance_validation_score.RSCC",
    "rcsb_nonpolymer_instance_validation_score.RSR",
    "rcsb_nonpolymer_instance_validation_score.alt_id",
    "rcsb_nonpolymer_instance_validation_score.completeness",
    "rcsb_nonpolymer_instance_validation_score.intermolecular_clashes",
    "rcsb_nonpolymer_instance_validation_score.is_best_instance",
    "rcsb_nonpolymer_instance_validation_score.is_subject_of_investigation",
    "rcsb_nonpolymer_instance_validation_score.mogul_angle_outliers",
    "rcsb_nonpolymer_instance_validation_score.mogul_angles_RMSZ",
    "rcsb_nonpolymer_instance_validation_score.mogul_bond_outliers",
    "rcsb_nonpolymer_instance_validation_score.mogul_bonds_RMSZ",
    "rcsb_nonpolymer_instance_validation_score.ranking_model_fit",
    "rcsb_nonpolymer_instance_validation_score.ranking_model_geometry",
    "rcsb_nonpolymer_instance_validation_score.score_model_fit",
    "rcsb_nonpolymer_instance_validation_score.score_model_geometry",
    "rcsb_nonpolymer_instance_validation_score.stereo_outliers",
    "rcsb_nonpolymer_instance_validation_score.type",
    "rcsb_nonpolymer_struct_conn.connect_type",
    "rcsb_nonpolymer_struct_conn.description",
    "rcsb_nonpolymer_struct_conn.dist_value",
    "rcsb_nonpolymer_struct_conn.id",
    "rcsb_nonpolymer_struct_conn.ordinal_id",
    "rcsb_nonpolymer_struct_conn.role",
    "rcsb_nonpolymer_struct_conn.value_order",
    "rcsb_nonpolymer_struct_conn.connect_target.auth_asym_id",
    "rcsb_nonpolymer_struct_conn.connect_target.auth_seq_id",
    "rcsb_nonpolymer_struct_conn.connect_target.label_alt_id",
    "rcsb_nonpolymer_struct_conn.connect_target.label_asym_id",
    "rcsb_nonpolymer_struct_conn.connect_target.label_atom_id",
    "rcsb_nonpolymer_struct_conn.connect_target.label_comp_id",
    "rcsb_nonpolymer_struct_conn.connect_target.label_seq_id",
    "rcsb_nonpolymer_struct_conn.connect_target.symmetry",
    "rcsb_nonpolymer_struct_conn.connect_partner.label_alt_id",
    "rcsb_nonpolymer_struct_conn.connect_partner.label_asym_id",
    "rcsb_nonpolymer_struct_conn.connect_partner.label_atom_id",
    "rcsb_nonpolymer_struct_conn.connect_partner.label_comp_id",
    "rcsb_nonpolymer_struct_conn.connect_partner.label_seq_id",
    "rcsb_nonpolymer_struct_conn.connect_partner.symmetry",
    "rcsb_target_neighbors.alt_id",
    "rcsb_target_neighbors.atom_id",
    "rcsb_target_neighbors.comp_id",
    "rcsb_target_neighbors.distance",
    "rcsb_target_neighbors.target_asym_id",
    "rcsb_target_neighbors.target_atom_id",
    "rcsb_target_neighbors.target_auth_seq_id",
    "rcsb_target_neighbors.target_comp_id",
    "rcsb_target_neighbors.target_entity_id",
    "rcsb_target_neighbors.target_is_bound",
    "rcsb_target_neighbors.target_model_id",
    "rcsb_target_neighbors.target_seq_id",
    "rcsb_uniprot_container_identifiers.uniprot_id",
    "rcsb_uniprot_container_identifiers.reference_sequence_identifiers.database_accession",
    "rcsb_uniprot_container_identifiers.reference_sequence_identifiers.database_isoform",
    "rcsb_uniprot_container_identifiers.reference_sequence_identifiers.database_name",
    "rcsb_uniprot_container_identifiers.reference_sequence_identifiers.provenance_source",
    "rcsb_uniprot_accession",
    "rcsb_uniprot_entry_name",
    "rcsb_uniprot_keyword.id",
    "rcsb_uniprot_keyword.value",
    "rcsb_uniprot_protein.sequence",
    "rcsb_uniprot_protein.name.value",
    "rcsb_uniprot_protein.name.provenance_code",
    "rcsb_uniprot_protein.function.details",
    "rcsb_uniprot_protein.function.provenance_code",
    "rcsb_uniprot_protein.gene.name.type",
    "rcsb_uniprot_protein.gene.name.value",
    "rcsb_uniprot_protein.source_organism.scientific_name",
    "rcsb_uniprot_protein.source_organism.taxonomy_id",
    "rcsb_uniprot_protein.source_organism.provenance_code",
    "rcsb_uniprot_protein.ec.number",
    "rcsb_uniprot_protein.ec.provenance_code",
    "rcsb_uniprot_feature.assignment_version",
    "rcsb_uniprot_feature.description",
    "rcsb_uniprot_feature.feature_id",
    "rcsb_uniprot_feature.name",
    "rcsb_uniprot_feature.provenance_source",
    "rcsb_uniprot_feature.reference_scheme",
    "rcsb_uniprot_feature.type",
    "rcsb_uniprot_feature.feature_positions.beg_comp_id",
    "rcsb_uniprot_feature.feature_positions.beg_seq_id",
    "rcsb_uniprot_feature.feature_positions.end_seq_id",
    "rcsb_uniprot_feature.feature_positions.value",
    "rcsb_uniprot_annotation.annotation_id",
    "rcsb_uniprot_annotation.assignment_version",
    "rcsb_uniprot_annotation.description",
    "rcsb_uniprot_annotation.name",
    "rcsb_uniprot_annotation.provenance_source",
    "rcsb_uniprot_annotation.type",
    "rcsb_uniprot_annotation.annotation_lineage.depth",
    "rcsb_uniprot_annotation.annotation_lineage.id",
    "rcsb_uniprot_annotation.annotation_lineage.name",
    "rcsb_uniprot_external_reference.reference_id",
    "rcsb_uniprot_external_reference.reference_name",
    "rcsb_uniprot_external_reference.provenance_source",
    "rcsb_uniprot_alignments.core_entity_alignments.scores.target_coverage",
    "rcsb_uniprot_alignments.core_entity_alignments.scores.query_coverage",
    "rcsb_uniprot_alignments.core_entity_alignments.scores.target_length",
    "rcsb_uniprot_alignments.core_entity_alignments.scores.query_length",
    "rcsb_uniprot_alignments.core_entity_alignments.aligned_regions.target_begin",
    "rcsb_uniprot_alignments.core_entity_alignments.aligned_regions.query_begin",
    "rcsb_uniprot_alignments.core_entity_alignments.aligned_regions.length",
    "rcsb_uniprot_alignments.core_entity_alignments.core_entity_identifiers.entry_id",
    "rcsb_uniprot_alignments.core_entity_alignments.core_entity_identifiers.entity_id",
]
